@@ -1385,9 +1385,9 @@ func checkToken(t *testing.T, tok json.Token, idx int, r R, in string) {
 	return
 }
 
-func errorf(t *testing.T, in string, fmtStr string, args ...any) {
+func errorf(t *testing.T, in string, fmtStr string, args ...interface{}) {
 	t.Helper()
-	vargs := []any{in}
+	vargs := []interface{}{in}
 	for _, arg := range args {
 		vargs = append(vargs, arg)
 	}
